@@ -8,7 +8,7 @@ import yaml
 import MySQLdb
 import MySQLdb.cursors
 # mine
-from HandwrittenData import HandwrittenData
+from hwrt.HandwrittenData import HandwrittenData
 import hwrt.utils as utils
 import hwrt.preprocessing as preprocessing
 import hwrt.features as features
